@@ -1,6 +1,6 @@
 <?php {
   /*
-   * $Id: dino_browser.php,v 1.18 2003/04/01 10:49:22 nishina Exp $
+   * $Id: dino_browser.php,v 1.22 2003/06/02 09:07:13 tishizak Exp $
    * Copyright (c) 2002-2003 Dino Co.,Ltd.
    */
 
@@ -111,22 +111,28 @@
      *
      */
     function get_terminal_type() {
-      $agent = $this->agent; //useragent
+      // $agent = $this->agent; //useragent
+      $agent = getenv("HTTP_USER_AGENT");
       $accept = getenv("HTTP_ACCEPT");
       $jphone = getenv("HTTP_X_JPHONE_MSNAME");
 
       if ( isset($jphone) && preg_match("/^J-PHONE/",$agent ) ) {
 	return "jphone";  //J-Phone
-
-      } elseif ( ereg("UP\.Browser",$agent) && ereg("hdml",$accept) ) {
+      } elseif ( preg_match("/^UP\.Browser\//",$agent) &&
+		 preg_match("/hdml/",$accept) ) {
+	// EZweb ü
+	return "ez";  //ez
+      } elseif ( preg_match("/^KDDI-[^ ]+ UP\.Browser\//", $agent) ) {
+	// EZweb WAP2.0 бü
 	return "ez";  //ez
-
       } elseif ( preg_match("/^DoCoMo/",$agent) ) {
 	return "docomo";  //DoCoMo
-
       } elseif ( preg_match("/^PDXGW/", $agent) ){	
 	return "pdx";  //H" 
-
+      } elseif ( preg_match("/^L-mode/",$agent) ) {
+	return "lmode";  //L-mode
+      } elseif ( preg_match("/^ASTEL/",$agent) ) {
+	return "doti";  //ɥåi
       } else {
 	return "etc";  //pc and unknown 
       }
@@ -326,9 +332,9 @@
 	}
 
 
-     } elseif ($this->terminal == "docomo" ) {
+      } elseif ($this->terminal == "docomo" ) {
 	//NTT DoCoMo
-       require_once(BROWSER_PROFILE_DIR."i_ver.inc");
+	require_once(BROWSER_PROFILE_DIR."i_ver.inc");
 
 	list( $docomo, $ver, $name, $sub) = split( "/", $this->agent );
 
@@ -458,9 +464,129 @@
       if($capname == "i-mode_emoji2"){
 	return $this->is_cap("i-mode_html_4.0"); //ɤ
       }
+    }
 
+    /**
+     * ʸϥȽ
+     *
+     * $mode͡
+     * string"hiragana","katakana","alphabet","numeric"
+     * 嵭ʳ boolean: false
+     *
+     * @param string $mode
+     * @return string ,or false
+     * @access public
+     */
+    function get_input_style($mode){
+      // $this->agent = getenv("HTTP_USER_AGENT");
+      if(Dino_Browser::get_terminal_type() == "docomo"){
+	if($mode == "hiragana")
+	  $style = "istyle='1'";
+	else if($mode == "katakana")
+	  $style = "istyle='2'";
+	else if($mode == "alphabet")
+	  $style = "istyle='3'";
+	else if($mode == "numeric")
+	  $style = "istyle='4'";
+      }
+      else if(Dino_Browser::get_terminal_type() == "jphone")
+	$style = 'mode="'.$mode.'"';
+      else if(Dino_Browser::get_terminal_type() == "ez"){
+	if($mode == "hiragana")
+	  $style = "FORMAT='*M'";
+	else if($mode == "katakana")
+	  $style = "FORMAT='*M'";
+	else if($mode == "alphabet")
+	  $style = "FORMAT='*m'";
+	else if($mode == "numeric")
+	  $style = "FORMAT='*N'";
+      }
+      else{
+	if($mode == "hiragana" || $mode == "katakana")
+	  $style = "STYLE='ime-mode:active'";
+	else if($mode == "alphabet" || $mode == "numeric")
+	  $style = "STYLE='ime-mode:disabled'";
+	else
+	  return false;
+      }
+      return $style;
+    }
 
+    /**
+     * mail address  validator
+     *
+     * $mail_add͡
+     * stringe-mail address
+     * 嵭ʳ boolean: false
+     *
+     * @param string $mail_add
+     * @return boolean
+     * @access public
+     * @todo PCѤΥɥ쥹ɽǧ
+     */
+    function valid_mail($mail_add){
+      $domain = strstr($mail_add, "@");
+      $tok = strtok($mail_add, "@");
+      if($domain == "@docomo.ne.jp")
+	if(preg_match("/^[a-zA-Z0-9\.\-\_]+$/i", $tok))
+	  return true;
+      else if($domain == "@ezweb.ne.jp")
+	if(preg_match("/^[a-zA-Z0-9\-][a-zA-Z0-9\.\-]*$/i", $tok))
+	  return true;
+      else if(preg_match("/^@jp-[a-z]\.ne\.jp$/i", $domain))
+	if(preg_match("/^[a-zA-Z0-9\+\-\?\/\_]+$/i", $tok))
+	  return true;
+      //PC?
+      //      else if(preg_match("/^@[0-9a-zA-Z\.\-]+[^\.]/i", $domain)){
+      //	if(preg_match("/^[0-9a-zA-Z\.\-]+/i", $tok))
+      //	  return true;
+      else
+	return false;
+    }
+
+    /**
+     * ü˹碌regexɥᥤ̵֤
+     *
+     *
+     * @return string or bool:false
+     * @access public
+     * @todo PCѤΥɥ쥹ɽǧ
+     */
+    function mail_addr_regex(){
+      if(Dino_Browser::get_terminal_type()== "docomo")
+	return "^[a-zA-Z0-9\.\-\_]+$";
+      else if(Dino_Browser::get_terminal_type()=="ez")
+	return "^[a-zA-Z0-9\-][a-zA-Z0-9\.\-]*$";
+      else if(Dino_Browser::get_terminal_type()=="jphone")
+	return "^[a-zA-Z0-9\+\-\?\/\_]+$";
+      //PC?
+      //      else if(preg_match("/^@[0-9a-zA-Z\.\-]+[^\.]/i", $domain)){
+      //	if(preg_match("/^[0-9a-zA-Z\.\-]+/i", $tok))
+      //	  return true;
+      else
+	return false;
+    }
+
+    /**
+     * ü˹碌regexɥᥤդ֤
+     *
+     * @return string or bool:false
+     * @access public
+     * @todo PCѤΥɥ쥹ɽǧ
+     */
+    function mail_fulladdr_regex(){
+      if(Dino_Browser::get_terminal_type()== "docomo")
+	return "^[a-zA-Z0-9\.\-\_]+\@docomo\.ne\.jp$";
+      else if(Dino_Browser::get_terminal_type()=="ez")
+	return "^[a-zA-Z0-9\-][a-zA-Z0-9\.\-]*\@ezweb\.ne\.jp$";
+      else if(Dino_Browser::get_terminal_type()=="jphone")
+	return "^[a-zA-Z0-9\+\-\?\/\_]+\@jp-[a-z]\.ne\.jp$";
+      //PC?
+      //      else if(preg_match("/^@[0-9a-zA-Z\.\-]+[^\.]/i", $domain)){
+      //	if(preg_match("/^[0-9a-zA-Z\.\-]+/i", $tok))
+      //	  return true;
+      else
+	return false;
     }
   }
-  
-}?>
+} ?>
