@@ -1,6 +1,6 @@
 <?php {
   /*
-   * $Id: dino_form.php,v 1.41 2003/04/01 11:06:32 nishina Exp $
+   * $Id: dino_form.php,v 1.45 2003/07/10 03:19:22 tumf Exp $
    * Copyright (c) 2002-2003 Dino Co.,Ltd.
    */
 
@@ -29,23 +29,38 @@
     var $elem_names = array();
 
     // ---------- public ----------
-    var $use_js = true; // falseʤJavaScriptvalidatorĤʤ
-    var $action = "";   // ǥեȤ$PHP_SELF
-    var $after_js = "";  // finish()JS񤯡
+    var $use_js = true; /**  falseʤJavaScriptvalidatorĤʤ */
+    var $use_post_method = true;    /** ᥽åɤλ   ǥեȤPOST */
+
+    var $action = "";   /** ǥեȤ$PHP_SELF */
+    var $after_js = "";  /**  finish()JS񤯡*/
     // $after_js="return check_submitting_once();" 2submitɻߤǤ롣
-    var $before_js = ""; // finish()JS񤯡
+    var $before_js = ""; /**  finish()JS񤯡*/
     //------------------------------
 
-    var $select_array = array();   // selectoptionꥹȤ¸array
-    var $default_value = array();  // default value¸array
+    var $select_array = array();   /** selectoptionꥹȤ¸array */
+    var $default_value = array();  /** default value¸array */
     var $select_array_year = array();
     var $select_array_month = array();
     var $select_array_day = array();
     var $select_array_hour = array();
     var $select_array_min = array();
 
-    //᥽åɤλ   ǥեȤPOST
-    var $use_post_method = true;
+
+    /**
+     * Dino_form 󥹥ȥ饯
+     *
+     */
+    function Dino_form(){
+      //֥饦μȽ̤method
+      if(!Dino_Browser::is_available_post_method()) {
+	$this->use_post_method = false;
+      }
+      //֥饦μȽ̤javascriptλѤ
+      if (!Dino_Browser::is_available_js()) {
+	$this->use_js = false;
+      }
+    }
 
     // ---------- private ----------
     function init_select_array_date() {
@@ -102,12 +117,28 @@
 	}
       }
     }
+    /**
+     * set default value.
+     *
+     * Set the form whose name is "$name" with value $value.
+     *
+     */
     // obsolete
     function set_default_value($name, $value) {
       $this->default_value[$name] = $value;
     }
 
-    // add_element()줿optionsɲä
+    /**
+     * append options.
+     *
+     * append options to form element.
+     * add_element()줿optionsɲä
+     *
+     *@access public
+     *@param string $name   form element`s name
+     *@param mixed $value  value of option
+     *@param string $label the label of value "$value" 
+     */
     function append_options($name, $value, $label="") {
       if (!is_array($value)) {
 	$this->form_data->elements[$name]["ob"]->options[] =
@@ -120,6 +151,12 @@
 	}
       }
     }
+    /**
+     * Change form`s default value.
+     *
+     * Change form`s default value with the name "$name" to "$value".
+     *
+     */
     function change_default_value($name, $value) {
       if (is_object($this->form_data->elements[$name]["ob"])) {
 	$this->form_data->elements[$name]["ob"]->value = $value;
@@ -141,8 +178,9 @@
       while (list($var, $value) = each($fv)) {
 	if (ereg("^[a-zA-Z_][a-zA-Z0-9_]*$", $var)) {
 	  if ($this->form_data->elements[$var]) {
-	    global $$var;
-	    $$var = $value;
+	    //global $$var;
+	    //$$var = $value;
+	    set_request_var($var,$value);
 	    $el_list[] = $var;
 	  }
 	}
@@ -153,7 +191,8 @@
       return true;
     }
     function pre_disp() {
-      global $form_name;
+      // global $form_name;
+      $form_name = request_var("form_name");
       if (! is_object($this->form_data)) {
 	$this->setup();
       }
