@@ -1,25 +1,64 @@
 <?php {
   /*
-   * $Id: dino_sql.php,v 1.75 2003/04/14 07:05:29 nishina Exp $
+   * $Id: dino_sql.php,v 1.86 2003/06/25 07:25:22 kasugai Exp $
    * Copyright(c) 2001-2003 Dino Co.,Ltd. All rights reserved.
    */
 
   /**
-   * DinoɸSQLʸ饹ݥ饹
+   * DinoɸSQLʸ饹SQLӥ/ݥ饹
    *
-   * ѾơĤΥơ֥ˤĤưĤΥ饹ޤ
-   * ʣΥơ֥ˤޤ褦ʾϡ
+   * ϤSQLξܺ٤ꤷSQLʸ֤Υ饹Ǥ
+   * Υ饹Ѿơǡ١ΰĤTABLEˤĤ
+   * Ĥζݥ饹ޤ
+   * ʣΥơ֥ˤޤ褦SQLꤿˤϡ
    * Ȥʤơ֥Υ饹Ƥ֤褦ˤޤ
    *
-   * 桼٥롿˱SQL֤褦ʵѰդƤޤ
+   * 㤨Сtestơ֥ˤĤƤΥ饹Test_SQLˤĤơ
+   * 
+   * $test_sql = new Test_SQL;
+   * $test_sql->initialize()
+   * $test_sql->set_condition("name", "dino");
+   * $test_sql->set_condition("value", 2003);
+   * $test_sql->set_orderby("atime");
+   * $sql = $test_sql->select();
+   * 
+   * Ȥȡ$sqlˤ
+   * "select * from test where name='dino' and value=2003 order by atime"
+   * ȤʸϤǤTest_SQLǤ
+   * 
+   * SQLʸ֤᥽åɤ select() / insert / update() delete() ʤɤǤ
+   * 
+   * Υ饹ȤåȤϰʲΤ褦ˤޤ
+   * 
+   * (1)SQLҤɸಽ
+   * 
+   * SQLʸϰ̤80ʸĶʸˤʤꡢ
+   * ʬʤɤSQLʸʸ˳ǼˡϿͤ줾Ǥ
+   * Τ褦ʥɤʣͿǤΥƥʥޤ
+   * 
+   * (2)SQLФϤSQLʸˡ顼ˤʤꥹ㸺
+   *
+   * ưSQLʸ뤿ᡢդ䥨顼å­ˤä
+   * SQLǽưǺ٤ƾ
+   *
+   * ä˾ˤäwhere­­ʤäꤹ
+   * SQL顼ˤʤꥹ򸺤餻ϤǤ롣
+   *
+   * ޤƥơ֥бݥ饹ơ֥λĥեɤ
+   * ̾䷿ξäƤ뤳ȤSQLɽˤʤ롣
+   * 
+   * (3)桼٥롿˱SQL֤뤳
    * 
    * 㤨С̥桼 class SQL_tableA_user extends Dino_SQL ʥ饹
    * Ԥʤ  class SQL_tableA_admin extends SQL_tableA_user ʥ饹
    * Ƥ֤褦ˤ줾˵줿SQLΤߤ֤褦ˤޤ
    *
-   * ǰʤ顢˽ɬSQLǤݾڤΤԲǽǤ
-   * ξϡƤӽФ¦ΥɤɬפϤǤ
-   * ߥ򸺤餹ˤʤΤǤϤʤǤ礦ʤäȼ嵤ġ
+   *
+   * ǰʤ顢Υ饹SQLʸǤäƤ
+   * Ф˥顼ФʤȤݾڤϤޤ
+   * ʤȤƥơ֥뤴ȤSQL饹ǤɬפϤޤ
+   * ξϡƤӽФ¦ΥɤǤΥ顼åɬפǤ礦
+   * ȤϤߥ򸺤餹ˤϤʤȹͤƤޤ
    *
    * todo:
    * debug Ĥ
@@ -84,7 +123,11 @@
      */
     var $update_fields = array();
 
-    // (field => ɽ٤)б
+   /**
+    * (field => ɽ٤)б
+    *
+    *@see set_labels(), get_labels()
+    */
     var $field_labels = array();
 
     /**
@@ -94,6 +137,8 @@
      *@param string  $alias     aliasʸ
      */
     function Dino_SQL($alias = "") {
+      $this->initialize();
+
       if ($alias) {
 	$this->set_alias($alias);
       }
@@ -106,12 +151,14 @@
      */
     function initialize() {
       $this->table = array();
+      $this->tableobj = array();
       $this->select = array();
       $this->where = array();
       $this->orderby = "";
       $this->desc = false;
       $this->limit = "";
       $this->offset = "";
+      $this->groupby = "";
     }
 
     /**
@@ -262,10 +309,24 @@
       }
     }
 
+   /**
+    * Set labels.
+    *
+    * (field => ɽ٤)б
+    *
+    *@param string $fname field name
+    *@param string $value field
+    *@param string $label ٥(ɽ٤)
+    */
     function set_labels($fname, $value, $label) {
       $this->field_labels[$fname][$value]=$label;
     }
 
+   /**
+    * Get labels
+    *
+    *@see set_labels()
+    */
     function get_labels($fname) {
       $a = $this->field_labels[$fname];
       if (is_array($a)) {
@@ -296,9 +357,10 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition($field, $value) {
-      $this->set_condition_op($field, "=", $value);
+      return $this->set_condition_op($field, "=", $value);
     }
     /**
      * ֡ĤϡĤ()ꤹ
@@ -310,9 +372,10 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_eq($field, $value) {
-      $this->set_condition_op($field, "=", $value);
+      return $this->set_condition_op($field, "=", $value);
     }
     /**
      * ֡ĤϡĤʤ()ꤹ
@@ -324,9 +387,10 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_ne($field, $value) {
-      $this->set_condition_op($field, "<>", $value);
+      return $this->set_condition_op($field, "<>", $value);
     }
     /**
      * ֡ĤϡĤ꾮()ꤹ
@@ -338,9 +402,10 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_lt($field, $value) {
-      $this->set_condition_op($field, "<", $value);
+      return $this->set_condition_op($field, "<", $value);
     }
     /**
      * ֡ĤϡĤޤϤ꾮()ꤹ
@@ -352,9 +417,10 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_le($field, $value) {
-      $this->set_condition_op($field, "<=", $value);
+      return $this->set_condition_op($field, "<=", $value);
     }
     /**
      * ֡ĤϡĤޤϤ꾮()ꤹ
@@ -366,9 +432,10 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_max($field, $value) {
-      $this->set_condition_op($field, "<=", $value);
+      return $this->set_condition_op($field, "<=", $value);
     }
     /**
      * ֡ĤϡĤ礭()ꤹ
@@ -380,9 +447,10 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_gt($field, $value) {
-      $this->set_condition_op($field, ">", $value);
+      return $this->set_condition_op($field, ">", $value);
     }
     /**
      * ֡ĤϡĤޤϤ礭()ꤹ
@@ -394,9 +462,10 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_ge($field, $value) {
-      $this->set_condition_op($field, ">=", $value);
+      return $this->set_condition_op($field, ">=", $value);
     }
     /**
      * ֡ĤϡĤޤϤ礭()ꤹ
@@ -408,18 +477,21 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_min($field, $value) {
-      $this->set_condition_op($field, ">=", $value);
+      return $this->set_condition_op($field, ">=", $value);
     }
     /**
      * ֡Ĥnullפꤹ
      *
      *@access public
      *@param string $field ե̾
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_null($field) {
       $this->where[$field] = $field. " is null";
+      return 0;
     }
     /**
      * ֡Ĥnullפꤹ
@@ -428,30 +500,36 @@
      *
      *@access public
      *@param string $field ե̾
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_is_null($field) {
       $this->set_condition_null($field);
+      return 0;
     }
     /**
      * ֡Ĥnullʤפꤹ
      *
      *@access public
      *@param string $field ե̾
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_is_not_null($field) {
       $this->where[$field."_is_not_null"] = $field. " is not null";
+      return 0;
     }
 
     /**
      * likeפꤹ
      *
-     * ΥեɤˤĤƤθ(where)Ȥ like 黻ҤȤޤ
-     * like黻ҤǤ %  _ üʸǤ
+     * ΥեɤˤĤƤθ(where)Ȥlike黻Ҥꤷޤ
+     * 3̾άѤޤ
+     * 3ά硢%  _ üʸǤ
      *
      *@access public
      *@param string $field ե̾
      *@param string $value 
-     *@param string $esc ʸ
+     *@param string $esc ʸʾάǽ
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_like($field, $value, $esc = "") {
       if (isset($value)) {
@@ -462,7 +540,9 @@
 	  $this->where[$field."_like"] = sprintf("%s like '%s'",
 						 $field, (string)$value, $esc);
 	}
+	return 0;
       }
+      return -1;
     }
 
     /**
@@ -474,6 +554,7 @@
      *@param string $field ե̾
      *@param string $from 
      *@param string $to 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_between($field, $from, $to) {
       if (isset($from) && isset($to)) {
@@ -481,7 +562,9 @@
 				       $field,
 				       $this->normalize_value($field, $from),
 				       $this->normalize_value($field, $to));
+	return 0;
       }
+      return -1;
     }
 
 
@@ -493,7 +576,7 @@
      * Ǥʤͤξ϶ʸ֤
      * ƤʤtextȤߤʤ
      *
-     *@access public
+     *@access private
      *@param string $field ե̾
      *@param string $value 
      *@return string 
@@ -548,6 +631,7 @@
      *@param string $field ե̾
      *@param string $op 黻
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_condition_op($field, $op, $value) {
       $opid_array = array(
@@ -568,6 +652,9 @@
       $where = $this->get_where_clause_op($field, $op, $value);
       if ($where) {
 	$this->where["${field}${opid}"] = $where;
+	return 0;
+      } else {
+	return -1;
       }
     }
 
@@ -583,6 +670,7 @@
      *@access public
      *@param string $field ե̾
      *@param string $value 
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function get_where_clause($field, $value='') {
       return $this->get_where_clause_op($field, "=", $value);
@@ -601,6 +689,7 @@
      *@param string $field ե̾
      *@param string $op 黻
      *@param string $value 
+     *@return string Ŭڤwhere1ġ顼ξ϶ʸ
      */
     function get_where_clause_op($field, $op, $value='') {
       $value = $this->normalize_value($field, $value);
@@ -701,7 +790,7 @@
       unset($this->where[$field]);
     }
     /**
-     * õ
+     * ľꤹ
      *
      * ʣwhereʤɡ
      * ¾δؿǤʤwhere1ʬľꤷޤ
@@ -797,11 +886,14 @@
      *
      *@access public
      *@param string $limit limitե̾
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_limit($limit) {
       if ($limit >= 0) {
 	$this->limit = (int)$limit;
+	return 0;
       }
+      return -1;
     } 
 
     /**
@@ -811,6 +903,7 @@
      *
      *@access public
      *@param string $offset offset ե̾
+     *@return int ｪλʤ0۾ｪλʤ-1
      */
     function set_offset($offset) {
       if ($offset >= 0) {
@@ -863,7 +956,7 @@
      */
     function set_condition_join_using($obj, $fields, $cfields=""){
 
-      if(!$fields) {
+      if(!$cfields) {
 	$cfields = $fields;
       }
       $field = $fields;
@@ -971,13 +1064,14 @@
     }
 
     /**
-     * ˹礦selectʸ֤
+     * ˹礦褦selectʸ֤
      *
      * set_condition()ʤɤƤ˱SQLʸ֤
      * 顼ʤɤͳŬڤSQLʸФʤ硢ʸ֤
      *
      *@access public
      *@param string $select selectե̾ά"*"
+     *@return string selectʸʸ󡣥顼ξʸ
      */
 
     function select($select = "") {
@@ -1055,13 +1149,13 @@
     }
 
     /**
-     * ˹礦selectʸ֤
+     * ˹礦褦select count(*)ʸ֤
      *
      * whereƤcount(*)SQL֤
-     * group byʣ֤select()Ȥ
      *
      *@access public
-     *@param string $field_name count(*)ˤĤ륨ꥢ̾ά"count"
+     *@param string $field_name count(*)פΥꥢ̾ͤ"count"
+     *@return string selectʸʸ󡣥顼ξʸ
      */
     function select_count($field_name = "count") {
 
@@ -1071,6 +1165,136 @@
 	$this->table = array($this->main_table);
       }
 
+      if (sizeof($this->tableobj) <= 0) {
+	// for backward-compatibility
+	$select_array = array($select);
+	if (sizeof($this->table) >= 1) {
+	  $from_array = $this->table;
+	} else {
+	  $from_array = array($this->main_table);
+	}
+	$where_array = $this->where;
+
+	// ŪorderbyˤΤǡϤ⤦ץˤʤϤ
+	if (!empty($this->orderby)) {
+	  $orderby = $this->orderby;
+	  if ($this->desc) {
+	    $orderby .= sprintf(" desc");
+	  }
+	  $orderby_array = array($orderby);
+	}
+
+      } else {
+	$select_array = array();
+	$from_array = array();
+	$where_array = array();
+	$orderby_array = array();
+
+	$ret = $this->traverse_sql_tree(&$select_array, &$from_array,
+					&$where_array, &$orderby_array);
+
+	$select_array = array($select);
+
+	if ($ret == false) {
+	  // error occured
+	  return "-- traverse_sql_tree() failed.";
+	}
+      }
+
+      $sql = sprintf("select count(*) as %s from %s", 
+		     $field_name,
+		     implode(",", $from_array));
+
+      if (sizeof($where_array)) {
+	$sql .= sprintf(" where %s", implode(" and ", $where_array));
+      }
+      if (!$this->condition_check()) { 
+	$this->_debug('select(): condition_check failed', $sql);
+	return "";
+      } else {
+	return $sql;
+      }
+    }
+
+    /**
+     * ˹礦褦select sum(...)ʸ֤
+     *
+     * whereƤsum(...)SQL֤
+     *
+     *@access public
+     *@param string $target_field פ׻ե̾
+     *@param string $field_alias sum(*)פΥꥢ̾ͤ"sum"
+     *@return string selectʸʸ󡣥顼ξʸ
+     */
+    function select_sum($target_field, $field_alias = "sum") {
+      /* ʲϾĹʤΤǡselect_count() ȤޤȤ᤿*/
+      if (is_array($this->table) && sizeof($this->table) > 0) {
+	// do nothing
+      } else {
+	$this->table = array($this->main_table);
+      }
+
+      if (sizeof($this->tableobj) <= 0) {
+	// for backward-compatibility
+	$select_array = array($select);
+	if (sizeof($this->table) >= 1) {
+	  $from_array = $this->table;
+	} else {
+	  $from_array = array($this->main_table);
+	}
+	$where_array = $this->where;
+
+	// ŪorderbyˤΤǡϤ⤦ץˤʤϤ
+	if (!empty($this->orderby)) {
+	  $orderby = $this->orderby;
+	  if ($this->desc) {
+	    $orderby .= sprintf(" desc");
+	  }
+	  $orderby_array = array($orderby);
+	}
+
+      } else {
+	$select_array = array();
+	$from_array = array();
+	$where_array = array();
+	$orderby_array = array();
+
+	$ret = $this->traverse_sql_tree(&$select_array, &$from_array,
+					&$where_array, &$orderby_array);
+
+	$select_array = array($select);
+
+	if ($ret == false) {
+	  // error occured
+	  return "-- traverse_sql_tree() failed.";
+	}
+      }
+
+      $sql = sprintf("select sum(%s) as %s from %s", 
+		     $target_field,
+		     $field_alias,
+		     implode(",", $from_array));
+
+      if (sizeof($where_array)) {
+	$sql .= sprintf(" where %s", implode(" and ", $where_array));
+      }
+      if (!$this->condition_check()) { 
+	$this->_debug('select(): condition_check failed', $sql);
+	return "";
+      } else {
+	return $sql;
+      }
+    }
+
+
+    function select_count_old($field_name = "count") {
+
+      if (is_array($this->table) && sizeof($this->table) > 0) {
+	// do nothing
+      } else {
+	$this->table = array($this->main_table);
+      }
+
       $sql = sprintf("select count(*) as %s from %s",
 		     $field_name,
 		     implode(",", $this->table));
@@ -1129,6 +1353,22 @@
       }
     }
 
+    /**
+     * ˹礦insertʸ֤
+     *
+     * ȤΥơ֥Ф$fvбŬڤinsertʸ֤
+     * 
+     * $fvϢǡSQLΥե̾ => SQL͡פȤġ
+     * 
+     * ޤset_condition()ƤȿǤinsertեɤ롣
+     * 
+     * 顼ʤɤͳŬڤSQLʸФʤ硢ʸ֤
+     *
+     *@access public
+     *@param string $fv ե̾򥭡ˤϢ
+     *@return string insertʸʸ󡣥顼ξʸ
+     */
+
     function insert(&$fv) {
       if (!is_array($fv))            { $this->_debug2('insert()'); return ""; }
       if (!$this->insert_fields)     { $this->_debug2('insert()'); return ""; }
@@ -1167,13 +1407,38 @@
       }
       return $sql;
     }
+
+    /**
+     * ˹礦褦updateʸ֤
+     *
+     * $fvϢͤĤ褦ʥ쥳ɤˤʤ褦
+     * updateʸ֤
+     * set_condition()ʤɤƤȿǤ롣
+     * 顼ʤɤͳŬڤSQLʸФʤ硢ʸ֤
+     *
+     *@access public
+     *@param string $fv ե̾򥭡ˤϢ
+     *@return string updateʸʸ󡣥顼ξʸ
+     */
+
     function update(&$fv) {
       $db = "";
       return $this->update_if_modified($fv, $db);
     }
 
-    // ƤʬΤ߹롣
-    // PostgreSQLѤjoinƤäƤŬڤSQLϤ롣
+    /**
+     * ˹礦褦ʡʬset褦updateʸ֤
+     *
+     * $fvϢͤĤ褦ʥ쥳ɤˤʤ褦ˡ
+     * ƤʬΤ߹褦updateʸ֤
+     * set_condition()ʤɤƤȿǤ롣
+     * 顼ʤɤͳŬڤSQLʸФʤ硢ʸ֤
+     *
+     *@access public
+     *@param string $fv ե̾򥭡ˤϢ
+     *@return string updateʸʸ󡣥顼ξʸ
+     */
+
     function update_if_modified(&$fv, &$db) {
       if (!is_array($fv))            { $this->_debug2('update()'); return ""; }
       if (!$this->update_fields)     { $this->_debug2('update()'); return ""; }
@@ -1232,6 +1497,16 @@
 	return $sql;
       }
     }
+
+    /**
+     * delete records.
+     *
+     * SQLʸdelete
+     * ߤwhere쥳ɤ
+     * whereꤵʤä顢⤷ʤ
+     *
+     *@return string $sql
+     */
     function delete() {
       if (!$this->condition_check_delete()) { return ""; }
 
