@@ -1,6 +1,6 @@
 <?php {
   /*
-   * $Id: dino_tpl2.php,v 1.20 2003/04/04 06:44:53 tumf Exp $
+   * $Id: dino_tpl2.php,v 1.22 2003/06/17 10:13:03 tumf Exp $
    * Copyright (c) 2002-2003 Dino Co.,Ltd.
    */
 
@@ -63,7 +63,8 @@
 	      "ksave"=>array("block","modifier"),
 	      "mbenc"=>array("modifier"),
   	      "escape" => array("function"), // block Ȥ...SmartyǤϡfunction /block Ƚ̤ʤ餷
-	      "emoji"=>"function"
+	      "emoji"=>"function",
+	      "contents" =>"function"
 	      );
     }
 
@@ -182,8 +183,8 @@
      *
      * @access public
      */
-    function set_tpl_form(&$f) {
-      $this->assign_by_ref('__form_obj', $f);
+    function set_tpl_form(&$f,$name="none") {
+      $this->_tpl_vars['__form_obj'][$name] = $f;
     }
 
     /**
