@@ -4,7 +4,7 @@
  * Copyright (c) 1998 by Jay Bloodworth
  * This file is modified by Dino Co.,Ltd.
  *
- * $Id: of_textarea.inc.php,v 1.11 2003/04/14 10:26:07 noriko Exp $
+ * $Id: of_textarea.inc.php,v 1.12 2003/05/23 13:06:12 hanawa Exp $
  */
 
 
@@ -44,7 +44,7 @@ class of_textarea extends of_element {
       $str .= " wrap='$this->wrap'";
     if ($this->extrahtml) 
       $str .= " $this->extrahtml";
-    $str .= " />" . htmlspecialchars($this->value, ENT_QUOTES) ."</textarea>";
+    $str .= ">" . htmlspecialchars($this->value, ENT_QUOTES) ."</textarea>";
     
     $count = 1;
     return $str;
@@ -57,7 +57,7 @@ class of_textarea extends of_element {
     $var  =  preg_replace("/\r/","",$var);
     $str .= "<input type='hidden' name='$this->name'";
     $str .= " value='";
-    $str .= $var . "' />\n";
+    $str .= $var . "'>\n";
     $str .= "<table cellspacing=0 cellpadding=0><tr><td>\n";
     $str .=  nl2br(htmlspecialchars($this->value, ENT_QUOTES));
     $str .= "\n</td></tr></table>\n";
