@@ -6,7 +6,7 @@
    * Smarty plugin
    * ----------------------------------------
    * File:    function.dino_tpl_form.php
-   * Id  :    $Id: function.dino_tpl_form.php,v 1.4 2003/03/13 14:34:12 noriko Exp $
+   * Id  :    $Id: function.dino_tpl_form.php,v 1.5 2003/06/17 10:13:03 tumf Exp $
    * Type:    function
    * Name:    tpl_form
    * Purpose: ƥץ졼ˡtmpl_formǤФե४֥Ȥ
@@ -27,7 +27,11 @@
        $t = $smarty->get_template_vars();
        $f = $t['__editform_obj'];
     */
-    $f = $smarty->_tpl_vars['__form_obj'];
+    $form_name="none";
+    if(strlen($params["form_name"])>0){
+      $form_name=$params["form_name"];
+    }
+    $f = $smarty->_tpl_vars['__form_obj'][$form_name];
     if($f) {
       if($params['type'] == 'start') {
 	print $f->get_start();
@@ -51,4 +55,5 @@
       }
     }
   }
+
 } ?>
